package com.devbeh;


import java.util.Arrays;
import java.util.Map;
import java.util.stream.Collectors;


public enum ActionClass
{
    // Daily Actions
    DROP(5), PICK_UP(6), THROW(7), SIT_DOWN(8), STAND_UP(9), CLAPPING(10), HAND_WAVING(23),
    KICKING_SOMETHING(24), REACH_INTO_POCKET(25), PHONE_CALL(28), SQUAT_DOWN(80), PUT_ON_BAG(87),
    TAKE_OFF_BAG(88), PUT_OBJECT_INTO_BAG(89), TAKE_OBJECT_OUT_OF_BAG(90), ARM_SWIGS(98),
    BUT_KICKS(100), SIDE_KICK(102),
    //Medical Conditions
    FALLING_DOWN(43),
    // Mutual Actions / Two Person Interactions
    PUNCH_SLAP(50), KICKING(51), PUSHING(52), GIVING_OBJECT(56), TOUCH_POCKET(57),
    SHAKING_HANDS(58), HIT_WITH_OBJECT(106), KNOCK_OVER(108), GRAB_STUFF(109), EXCHANGE_THINGS(118);

    /**
     * Идентификатор класса, возвращаемый детектором.
     */
    private final int id;


    ActionClass(int id)
    {
        this.id = id;
    }


    public int getId()
    {
        return id;
    }


    private static final Map<Integer, ActionClass> ID_TO_ACTION_CLASS;
    static {
        ID_TO_ACTION_CLASS = Arrays.stream(values()).collect(Collectors.toMap(ActionClass::getId, e -> e));
    }


    /**
     * Возвращает экземпляр {@link ActionClass} по идентификатору класса.
     *
     * @param id идентификатор класса
     * @return экземпляр {@link ActionClass} или null
     */
    public static ActionClass findById(int id)
    {
        return ID_TO_ACTION_CLASS.get(id);
    }
}
